@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::App;
-$Footprintless::App::VERSION = '1.16';
+$Footprintless::App::VERSION = '1.17';
 # ABSTRACT: The base application class for fpl
 # PODNAME: Footprintless::App
 
@@ -13,34 +13,14 @@ use Log::Any;
 
 my $logger = Log::Any->get_logger();
 
-my $pretend_self = {};
-
 # todo: remove after https://github.com/rjbs/App-Cmd/pull/60
-sub _new {
-    my ( $class, $arg ) = @_;
-
-    my $arg0 = $0;
-    require File::Basename;
-    my $base = File::Basename::basename $arg0;
-
-    my $self = bless(
-        {   arg0         => $base,
-            full_arg0    => $arg0,
-            show_version => $arg->{show_version_cmd} || 0,
-        },
-        $class
-    );
-
-    $self->{command} = $self->_command($arg);
-
-    return $self;
-}
+my $pretend_self = {};
 
 sub _configure_logging {
     my ( $self, %options ) = @_;
 
     my $log_configurator_module =
-        footprintless()->entities()->get_entity('footprintless.log_configurator');
+        $self->footprintless()->entities()->get_entity('footprintless.log_configurator');
     if ($log_configurator_module) {
         dynamic_module_new($log_configurator_module)->configure(%options);
     }
@@ -51,14 +31,20 @@ sub _configure_logging {
     }
 }
 
+sub clear_pretend_self {
+
+    #used by unit tests to clear out predend self hack between tests
+    $pretend_self = {};
+}
+
 sub footprintless {
     my ($self) = @_;
 
-    if ( !defined( $self->{footprintless} ) ) {
-        $self->{footprintless} = Footprintless->new();
+    if ( !defined( $pretend_self->{footprintless} ) ) {
+        $pretend_self->{footprintless} = Footprintless->new();
     }
 
-    return $self->{footprintless};
+    return $pretend_self->{footprintless};
 }
 
 sub get_command {
@@ -82,10 +68,13 @@ sub global_opt_spec {
 
 # todo: remove after https://github.com/rjbs/App-Cmd/pull/60
 sub footprintless_plugin_search_paths {
+    my ($self) = @_;
+
     my @paths = ();
-    foreach my $plugin ( footprintless($pretend_self)->plugins() ) {
+    foreach my $plugin ( $self->footprintless()->plugins() ) {
         push( @paths, $plugin->command_packages() );
     }
+
     return @paths;
 }
 
@@ -124,7 +113,7 @@ Footprintless::App - The base application class for fpl
 
 =head1 VERSION
 
-version 1.16
+version 1.17
 
 =head1 METHODS
 
@@ -163,6 +152,6 @@ L<Footprintless|Footprintless>
 
 =back
 
-=for Pod::Coverage get_command global_opt_spec footprintless_plugin_search_paths REAL_footprintless_plugin_search_paths plugin_search_path
+=for Pod::Coverage clear_pretend_self get_command global_opt_spec footprintless_plugin_search_paths REAL_footprintless_plugin_search_paths plugin_search_path
 
 =cut
